
# Tutorial - Factory Reset Configuration

In this simple tutorial the factory reset of the device configuration is exampled. This will reset the non-volatile memory storing the unit callsign, default frequency, and other settings to factory defaults.


#Running The Tutorial Example Script

## Start The Proxy Interface

Following the [Configuring Proxy](../../0-Welcome_To_Faraday/Configuring_Proxy/) tutorial configure, start, and ensure a successful connection to a locally (USB) connected Faraday digital radio.


## Tutorial Output Examples


# Code Overview

## Code - Parse Telemetry Packet Type #1 (System Operation)




